@@ -66,8 +66,8 @@ class CrossSectionFloatCheck(CrossSectionBaseCheck):
         return f"{self.column_name} should be a positive number for shapes {self.shape_msg}"
 
 
-class CrossSectionNonZeroCheck(CrossSectionBaseCheck):
-    """Check that width / height is larger than >0"""
+class CrossSectionGreaterZeroCheck(CrossSectionBaseCheck):
+    """Check that width / height is larger than 0"""
 
     def get_invalid(self, session):
         invalids = []
@@ -79,12 +79,12 @@ class CrossSectionNonZeroCheck(CrossSectionBaseCheck):
             except ValueError:
                 continue
 
-            if value == 0:
+            if value <= 0:
                 invalids.append(record)
         return invalids
 
     def description(self):
-        return f"{self.column_name} should be nonzero for shapes {self.shape_msg}"
+        return f"{self.column_name} should be greater than zero for shapes {self.shape_msg}"
 
 
 class CrossSectionFloatListCheck(CrossSectionBaseCheck):
@@ -161,8 +161,32 @@ class CrossSectionIncreasingCheck(CrossSectionBaseCheck):
         return f"{self.column_name} should be monotonically increasing for shapes {self.shape_msg}. Maybe the width and height have been interchanged?"
 
 
+class CrossSectionFirstElementZeroCheck(CrossSectionBaseCheck):
+    """Tabulated definitions should start at with 0 height."""
+
+    def get_invalid(self, session):
+        invalids = []
+        for record in self.to_check(session).filter(
+            (self.column != None) & (self.column != "")
+        ):
+            try:
+                values = [
+                    float(x) for x in getattr(record, self.column.name).split(" ")
+                ]
+            except ValueError:
+                continue  # other check catches this
+
+            if abs(values[0]) != 0:
+                invalids.append(record)
+
+        return invalids
+
+    def description(self):
+        return f"The first element of {self.column_name} should equal 0 for shapes {self.shape_msg}. Note that heights are relative to 'reference_level'."
+
+
 class CrossSectionFirstElementNonZeroCheck(CrossSectionBaseCheck):
-    """Tabulated definitions should have an increasing list of heights."""
+    """Tabulated rectangles cannot start with 0 width."""
 
     def get_invalid(self, session):
         invalids = []
@@ -182,4 +206,4 @@ class CrossSectionFirstElementNonZeroCheck(CrossSectionBaseCheck):
         return invalids
 
     def description(self):
-        return f"The first element of {self.column_name} should be larger than 0 for shapes {self.shape_msg}. Zero as first value may lead to numerical issues."
+        return f"The first element of {self.column_name} must be larger than 0 for tabulated rectangle shapes. Consider using tabulated trapezium."
