@@ -13,8 +13,8 @@ from .checks.cross_section_definitions import (
 from .checks.cross_section_definitions import CrossSectionFirstElementZeroCheck
 from .checks.cross_section_definitions import CrossSectionFloatCheck
 from .checks.cross_section_definitions import CrossSectionFloatListCheck
+from .checks.cross_section_definitions import CrossSectionGreaterZeroCheck
 from .checks.cross_section_definitions import CrossSectionIncreasingCheck
-from .checks.cross_section_definitions import CrossSectionNonZeroCheck
 from .checks.cross_section_definitions import CrossSectionNullCheck
 from .checks.factories import generate_enum_checks
 from .checks.factories import generate_foreign_key_checks
@@ -60,6 +60,11 @@ CONDITIONS = {
     ),
 }
 
+try:
+    kmax = Query(models.GlobalSetting.kmax).limit(1).scalar_subquery()
+except AttributeError:
+    kmax = Query(models.GlobalSetting.kmax).limit(1).as_scalar()
+
 CHECKS: List[BaseCheck] = []
 
 ## 002x: FRICTION
@@ -315,9 +320,8 @@ CHECKS += [
         column=models.CrossSectionDefinition.height,
         shapes=(constants.CrossSectionShape.CLOSED_RECTANGLE,),
     ),
-    CrossSectionNonZeroCheck(
+    CrossSectionGreaterZeroCheck(
         error_code=85,
-        level=CheckLevel.WARNING,
         column=models.CrossSectionDefinition.width,
         shapes=(
             constants.CrossSectionShape.RECTANGLE,
@@ -326,9 +330,8 @@ CHECKS += [
             constants.CrossSectionShape.EGG,
         ),
     ),
-    CrossSectionNonZeroCheck(
+    CrossSectionGreaterZeroCheck(
         error_code=86,
-        level=CheckLevel.WARNING,
         column=models.CrossSectionDefinition.height,
         shapes=(constants.CrossSectionShape.CLOSED_RECTANGLE,),
     ),
@@ -365,7 +368,6 @@ CHECKS += [
     ),
     CrossSectionFirstElementNonZeroCheck(
         error_code=91,
-        level=CheckLevel.WARNING,
         column=models.CrossSectionDefinition.width,
         shapes=(constants.CrossSectionShape.TABULATED_RECTANGLE,),
     ),
@@ -1157,6 +1159,24 @@ CHECKS += [
     ),
 ]
 
+## 080x: refinement levels
+CHECKS += [
+    QueryCheck(
+        error_code=800,
+        column=model.refinement_level,
+        invalid=Query(model).filter(model.refinement_level > kmax),
+        message=f"{model.__table__.name}.refinement_level must not be greater than v2_global_settings.kmax",
+    )
+    for model in (models.GridRefinement, models.GridRefinementArea)
+]
+CHECKS += [
+    RangeCheck(
+        error_code=801,
+        column=model.refinement_level,
+        min_value=1,
+    )
+    for model in (models.GridRefinement, models.GridRefinementArea)
+]
 
 ## 110x: SIMULATION SETTINGS, timestep
 CHECKS += [
@@ -1324,13 +1344,6 @@ CHECKS += [
         error_code=1124,
         column=models.GlobalSetting.flooding_threshold,
         min_value=0,
-        max_value=0.3,
-    ),
-    RangeCheck(
-        error_code=1124,
-        level=CheckLevel.WARNING,
-        column=models.GlobalSetting.flooding_threshold,
-        min_value=0,
         max_value=0.05,
     ),
     QueryCheck(
